import requests
import urllib
import urllib.request
from asyncio import run, gather

class webapi:

    @staticmethod
    def run(apikey, text, sound, filename):
        params = {'apikey': apikey,
                  'text': text,
                  'sound': sound,
                  'filename': filename,
                  }
        post = requests.get(f"https://api.su-shiki.com/v2/voicevox/audio/?key={apikey}&speaker={sound}&pitch=0&intonationScale=1&speed=1&text={text}")
        with open(f"{filename}.wav", "wb") as fp:
            fp.write(post.content)


# Author: Kenta Nakamura <c60evaporator@gmail.com>
# Copyright (c) 2020-2021 Kenta Nakamura
# License: BSD 3 clause

from setuptools import setup
import voicevox

DESCRIPTION = "Python上から簡単にVORCEVOXの音声合成を利用できるモジュール。"
NAME = 'voicevox.py'
AUTHOR = 'sonyakun'
AUTHOR_EMAIL = 'sonyaumg@gmail.com'
URL = 'https://github.com/sonyakun/voicevox.py'
LICENSE = 'MIT'
VERSION = "1.0.2"
PYTHON_REQUIRES = ">=3.6"

INSTALL_REQUIRES = [
    'asyncio',
    'requests',
    'urllib3',
]

EXTRAS_REQUIRE = {
    'tutorial': [
        'mlxtend>=0.18.0',
        'xgboost>=1.4.2',
    ]
}

PACKAGES = [
    'voicevox'
]

CLASSIFIERS = [
    'Intended Audience :: Science/Research',
    'License :: OSI Approved :: BSD License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3 :: Only',
    'Topic :: Scientific/Engineering',
    'Topic :: Scientific/Engineering :: Visualization',
    'Topic :: Scientific/Engineering :: Artificial Intelligence',
    'Topic :: Multimedia :: Graphics',
    'Framework :: Matplotlib',
]


readme = "README.md"
long_description = readme

setup(name=NAME,
      author=AUTHOR,
      author_email=AUTHOR_EMAIL,
      maintainer=AUTHOR,
      maintainer_email=AUTHOR_EMAIL,
      description=DESCRIPTION,
      long_description=long_description,
      license=LICENSE,
      url=URL,
      version=VERSION,
      python_requires=PYTHON_REQUIRES,
      install_requires=INSTALL_REQUIRES,
      extras_require=EXTRAS_REQUIRE,
      packages=PACKAGES,
      classifiers=CLASSIFIERS
    )


import json
import requests
import wave
import subprocess
import asyncio
import urllib.request
import platform


class voiceclient:

    @staticmethod
    def app(exepass):
        subprocess.Popen(exepass)

    @staticmethod
    def run(text, speaker, filename):
        query_payload = {"text": text, "speaker": speaker}
        r = requests.post("http://localhost:50021/audio_query", 
        params=query_payload, timeout=(10.0, 300.0))
        query_data = r.json()
        synth_payload = {"speaker": speaker}    
        r = requests.post("http://localhost:50021/synthesis", params=synth_payload, data=json.dumps(query_data))
        with open(filename, "wb") as fp:
            fp.write(r.content)

    @staticmethod
    def vbox_dl():
        pf = platform.system()
        if pf == 'Windows':
            url = "https://github.com/VOICEVOX/voicevox/releases/download/0.13.1/VOICEVOX.Web.Setup.0.13.1.exe"
            urllib.request.urlretrieve(url, 'voicevox.exe')
            subprocess.run("voicevox.exe")
        elif pf == 'Darwin':
            url = "https://github.com/VOICEVOX/voicevox/releases/download/0.13.1/VOICEVOX.0.13.1.dmg"
            urllib.request.urlretrieve(url, 'voicevox.dmg')
            subprocess.run("voicevox.dmg", shell=True)
        elif pf == 'Linux':
            url = "https://voicevox.hiroshiba.jp/static/5a524c78055a8eb31039f9d8e9462623/linuxInstallNvidia.sh"
            urllib.request.urlretrieve(url, 'voicevox.sh')
            subprocess.run("voicevox.sh", shell=True)
